Quickstart
==========

By way of introduction, let's start with some example usages of Avulto.

.. toctree::
   map_modification
   icon_parsing
   environment_parsing
   putting_it_all_together
   conclusion
